OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Sandi salah",
    "No user supplied" : "Tidak ada pengguna yang diberikan",
    "Authentication error" : "Terjadi kesalahan saat otentikasi",
    "Wrong admin recovery password. Please check the password and try again." : "Sandi pemulihan admin salah. Periksa sandi dan ulangi kembali.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Backend tidak mendukung pengubahan sandi, tapi kunci enkripsi pengguna berhasil diperbarui.",
    "Unable to change password" : "Tidak dapat mengubah sandi",
    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "memasang dan memperbarui aplikasi via toko aplikasi atau Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL menggunakan versi lawas %s (%s). Silakan perbarui sistem operasi Anda atau fitur-fitur seperti %s tidak akan dapat bekerja dengan benar.",
    "A problem occurred, please check your log files (Error: %s)" : "Terjadi masalah, mohon periksa berkas log Anda (Kesalahan: %s)",
    "Migration Completed" : "Migrasi Selesai",
    "Group already exists." : "Grup sudah ada.",
    "Unable to add group." : "Tidak dapat menambah grup.",
    "Unable to delete group." : "Tidak dapat menghapus grup.",
    "log-level out of allowed range" : "level-log melebihi batas yang diizinkan",
    "Saved" : "Disimpan",
    "test email settings" : "pengaturan email percobaan",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Terjadi masalah saat mengirim email. Mohon periksa kembali pengaturan Anda. (Kesalahan: %s)",
    "Email sent" : "Email terkirim",
    "You need to set your user email before being able to send test emails." : "Anda perlu menetapkan email pengguna Anda sebelum dapat mengirim email percobaan.",
    "Invalid mail address" : "Alamat email salah",
    "A user with that name already exists." : "Pengguna dengan nama tersebut sudah ada.",
    "Unable to create user." : "Tidak dapat membuat pengguna.",
    "Your %s account was created" : "Akun %s Anda telah dibuat",
    "Unable to delete user." : "Tidak dapat menghapus pengguna.",
    "Forbidden" : "Terlarang",
    "Invalid user" : "Pengguna salah",
    "Unable to change mail address" : "Tidak dapat mengubah alamat email",
    "Your full name has been changed." : "Nama lengkap Anda telah diubah",
    "Unable to change full name" : "Tidak dapat mengubah nama lengkap",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "__language_name__",
    "Language changed" : "Bahasa telah diubah",
    "Invalid request" : "Permintaan tidak valid",
    "Admins can't remove themself from the admin group" : "Admin tidak dapat menghapus dirinya sendiri dari grup admin",
    "Unknown user" : "Pengguna tidak dikenal",
    "Couldn't remove app." : "Tidak dapat menghapus aplikasi.",
    "Official" : "Resmi",
    "Approved" : "Disetujui",
    "All" : "Semua",
    "Enabled" : "Diaktifkan",
    "Not enabled" : "Tidak diaktifkan",
    "No apps found for your version" : "Aplikasi tidak ditemukan untuk versi ini.",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplikasi resmi dikembangkan oleh komunitas ownCloud. Mereka menawarkan fitur pusat bagi ownCloud dan siap digunakan untuk penggunaan produksi.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Aplikasi tersetujui dikembangkan oleh pengembang terpercaya dan telah lulus pemeriksaan keamanan. Mereka secara aktif dipelihara direpositori kode terbuka dan pemelihara sudah memastikan mereka stabil untuk penggunaan normal.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Apl ini belum diperiksa masalah keamanannya dan masih baru atau biasanya tidak stabil. Instal dengan resiko Anda sendiri.",
    "Please wait...." : "Mohon tunggu....",
    "Error while disabling app" : "Terjadi kesalahan saat menonaktifkan aplikasi",
    "Disable" : "Nonaktifkan",
    "Enable" : "Aktifkan",
    "Error while enabling app" : "Terjadi kesalahan saat mengakifkan aplikasi",
    "Updating...." : "Memperbarui....",
    "Error while updating app" : "Terjadi kesalahan saat memperbarui aplikasi",
    "Updated" : "Diperbarui",
    "Uninstalling ...." : "Mencopot ...",
    "Error while uninstalling app" : "Terjadi kesalahan saat mencopot aplikasi",
    "Uninstall" : "Copot",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikasi sudah diaktifkan tetapi perlu diperbarui. Anda akan dialihkan ke halaman pembaruan dalam 5 detik.",
    "App update" : "Pembaruan Aplikasi",
    "Experimental" : "Uji Coba",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Apakah Anda yakin ingin menambahkan \"{domain}\" sebagai domain terpercaya?",
    "Add trusted domain" : "Tambah domain terpercaya",
    "Migration in progress. Please wait until the migration is finished" : "Migrasi sedang dalam proses. Mohon tunggu sampai migrasi selesai.",
    "Migration started …" : "Migrasi dimulai ...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Terjadi kesalahan. Mohon unggah sertifikat PEM terenkode-ASCII.",
    "Valid until {date}" : "Berlaku sampai {date}",
    "Delete" : "Hapus",
    "Sending..." : "Mengirim",
    "An error occurred: {message}" : "Sebuah kesalahan yang muncul: {message}",
    "Select a profile picture" : "Pilih foto profil",
    "Very weak password" : "Sandi sangat lemah",
    "Weak password" : "Sandi lemah",
    "So-so password" : "Sandi lumayan",
    "Good password" : "Sandi baik",
    "Strong password" : "Sandi kuat",
    "Groups" : "Grup",
    "Unable to delete {objName}" : "Tidak dapat menghapus {objName}",
    "A valid group name must be provided" : "Harus memberikan nama grup yang benar.",
    "deleted {groupName}" : "menghapus {groupName}",
    "undo" : "urungkan",
    "never" : "tidak pernah",
    "deleted {userName}" : "menghapus {userName}",
    "add group" : "tambah grup",
    "enabled" : "diaktifkan",
    "disabled" : "dinonaktifkan",
    "no group" : "tanpa grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Pengubahan kata sandi akan ditampilkan di data kehilangan, karena data pemulihan tidak tersedia bagi pengguna ini",
    "A valid username must be provided" : "Harus memberikan nama pengguna yang benar",
    "A valid password must be provided" : "Harus memberikan sandi yang benar",
    "A valid email must be provided" : "Email yang benar harus diberikan",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hai,<br><br>sekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.<br><br>Nama Pengguna Anda: %s<br>Akses di: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Horee!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hai,\n\nsekedar memberi tahu bahwa Andaa sekarang memiliki akun %s.\n\nNama Pengguna Anda: %s\nAkses di: %s\n",
    "User documentation" : "Dokumentasi pengguna.",
    "Administrator documentation" : "Dokumentasi administrator",
    "Online documentation" : "Dokumentasi online",
    "Forum" : "Forum",
    "Issue tracker" : "Pelacak masalah",
    "Commercial support" : "Dukungan komersial",
    "Developer documentation" : "Dokumentasi pengembang",
    "Documentation:" : "Dokumentasi:",
    "Admin documentation" : "Dokumentasi admin",
    "Show description …" : "Tampilkan deskripsi ...",
    "Hide description …" : "Sembunyikan deskripsi ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Apl ini tidak dapat diinstal karena ketergantungan berikut belum terpenuhi:",
    "Enable only for specific groups" : "Aktifkan hanya untuk grup tertentu",
    "Uninstall App" : "Copot aplikasi",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Eksekusi penjadwalan cron terakhir: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Eksekusi penjadwalan cron terakhir: %s. Kelihatannya ada yang salah.",
    "Cron was not executed yet!" : "Cron masih belum dieksekusi!",
    "Open documentation" : "Buka dokumentasi",
    "Execute one task with each page loaded" : "Jalankan tugas setiap kali halaman dimuat",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php didaftarkan pada layanan webcron untuk memanggil cron.php setiap 15 menit melalui http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Gunakan layanan cron sistem untuk memanggil berkas cron.php setiap 15 menit.",
    "Common Name" : "Nama umum",
    "Valid until" : "Berlaku sampai",
    "Issued By" : "Diterbitkan oleh",
    "Valid until %s" : "Berlaku sampai %s",
    "Import root certificate" : "Impor sertifikat root",
    "Server-side encryption" : "Enkripsi sisi-server",
    "Enable server-side encryption" : "Aktifkan enkripsi sisi-server",
    "Please read carefully before activating server-side encryption: " : "Mohon baca dengan teliti sebelum mengaktifkan enkripsi server-side:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Setelah enkripsi diaktifkan, semua berkas yang diunggah pada server mulai saat ini akan dienkripsi saat singgah pada server. Penonaktifan enkripsi hanya mungkin berhasil jika modul enkripsi yang aktif mendukung fungsi ini dan semua prasyarat (misalnya pengaturan kunci pemulihan) sudah terpenuhi.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Enkripsi saja tidak menjamin keamanan sistem. Silakan lihat dokumentasi ownCloud untuk informasi lebih lanjut tentang bagaimana aplikasi enkripsi bekerja, dan kasus penggunaan yang didukung.",
    "Be aware that encryption always increases the file size." : "Ingat bahwa enkripsi selalu menambah ukuran berkas.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Alangkah baiknya untuk membuat cadangan data secara rutin, dalam kasus enkripsi, pastikan untuk mencadangkan kunci enkripsi bersama dengan data Anda.",
    "This is the final warning: Do you really want to enable encryption?" : "Ini adalah peringatan terakhir: Apakah Anda yakin ingin mengaktifkan enkripsi?",
    "Enable encryption" : "Aktifkan enkripsi",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Tidak ada modul enkripsi yang dimuat, mohon aktifkan modul enkripsi di menu aplikasi.",
    "Select default encryption module:" : "Pilih modul enkripsi baku:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Anda perlu mengganti kunci enkrispi Anda dari enkripsi lama (ownCloud <= 8.0) ke yang baru. Mohon aktifkan \"Modul enkripsi standar\" dan jalankan 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Anda perlu untuk mengubah kunci enkripsi dari enkripsi lama (ownCloud <= 8.0) ke yang baru.",
    "Start migration" : "Mulai migrasi",
    "Sharing" : "Berbagi",
    "Allow apps to use the Share API" : "Izinkan aplikasi untuk menggunakan API Pembagian",
    "Allow users to share via link" : "Izinkan pengguna untuk membagikan via tautan",
    "Allow public uploads" : "Izinkan unggahan publik",
    "Enforce password protection" : "Berlakukan perlindungan sandi",
    "Set default expiration date" : "Atur tanggal kadaluarsa default",
    "Allow users to send mail notification for shared files" : "Izinkan pengguna untuk mengirimkan email pemberitahuan untuk berkas berbagi",
    "Expire after " : "Kadaluarsa setelah",
    "days" : "hari",
    "Enforce expiration date" : "Berlakukan tanggal kadaluarsa",
    "Allow resharing" : "Izinkan pembagian ulang",
    "Restrict users to only share with users in their groups" : "Batasi pengguna untuk hanya membagikan dengan pengguna didalam grup mereka",
    "Allow users to send mail notification for shared files to other users" : "Izinkan pengguna mengirim pemberitahuan email saat berbagi berkas kepada pengguna lainnya",
    "Exclude groups from sharing" : "Tidak termasuk grup untuk berbagi",
    "These groups will still be able to receive shares, but not to initiate them." : "Grup ini akan tetap dapat menerima berbagi, tatapi tidak dapat membagikan.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Izinkan penyelesai otomatis pada nama pengguna di jendela dialog berbagi. Jika ini dinonaktifkan, nama pengguna utuh perlu dimasukkan.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Semuanya (Masalah fatal, kesalahan, peringatan, info, debug)",
    "Info, warnings, errors and fatal issues" : "Info, peringatan, kesalahan dan masalah fatal",
    "Warnings, errors and fatal issues" : "Peringatan, kesalahan dan masalah fatal",
    "Errors and fatal issues" : "Kesalahan dan masalah fatal",
    "Fatal issues only" : "Hanya masalah fatal",
    "Log" : "Log",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Berkas log lebih besar dari 100MB. Pengunduhan ini memerlukan beberapa saat!",
    "None" : "Tidak ada",
    "Login" : "Masuk",
    "Plain" : "Biasa",
    "NT LAN Manager" : "Manajer NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server email",
    "This is used for sending out notifications." : "Ini digunakan untuk mengirim notifikasi keluar.",
    "Send mode" : "Modus kirim",
    "Encryption" : "Enkripsi",
    "From address" : "Dari alamat",
    "mail" : "email",
    "Authentication method" : "Metode otentikasi",
    "Authentication required" : "Diperlukan otentikasi",
    "Server address" : "Alamat server",
    "Port" : "Port",
    "Credentials" : "Kredensial",
    "SMTP Username" : "Nama pengguna SMTP",
    "SMTP Password" : "Sandi SMTP",
    "Store credentials" : "Simpan kredensial",
    "Test email settings" : "Pengaturan email percobaan",
    "Send email" : "Kirim email",
    "Security & setup warnings" : "Peringatan Keamanan & Pengaturan",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "kelihatannya php tidak diatur dengan benar untuk variabel lingkungan sistem kueri. Pemeriksaan dengan getenv(\"PATH\") hanya mengembalikan respon kosong.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfig Hanya-Baca telah diaktifkan. Ini akan mencegah setelan beberapa konfigurasi melalui antarmuka-web. Selanjutnya, berkas perlu dibuat dapat-dibaca secara manual untuk setiap pembaruan.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP tampaknya disetel menjadi strip inline doc blocks. Hal ini akan membuat beberapa aplikasi inti tidak dapat diakses.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Module 'fileinfo' pada PHP tidak ada. Kami sangat menyarankan untuk mengaktifkan modul ini untuk mendapatkan hasil terbaik pada proses pendeteksian mime-type.",
    "System locale can not be set to a one which supports UTF-8." : "Sistem lokal tidak dapat diatur untuk satu yang mendukung UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Ini artinya mungkin ada masalah dengan karakter tertentu pada nama berkas.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Kamu sangat menyarankan untuk menginstal paket-paket yang dibutuhkan pada sistem agar mendukung lokal berikut: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Jika instalasi Anda tidak di root domain dan menggunakan sistem cron, hal tersebut dapat menyebabkan masalah dengan pembuatan URL. Untuk mencegah masalah tersebut, mohon atur opsi \"overwrite.cli.url\" pada berkas config.php Anda ke jalur lokasi webroot instalasi Anda (Disarankan: \"%s\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite digunakan sebagai basis data. Untuk instalasi yang lebih besar, kami menyarankan untuk beralih ke backend basis data yang berbeda.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Terutama saat menggunakan klien desktop untuk sinkronisasi berkas, penggunaan SQLite tidak disarankan.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Tidak mungkin untuk mengeksekusi cronjob via CLI. Kesalahan teknis berikut muncul:",
    "All checks passed." : "Semua pemeriksaan lulus.",
    "Tips & tricks" : "Tips & trik",
    "How to do backups" : "Bagaimana cara membuat cadangan",
    "Advanced monitoring" : "Pemantauan tingkat lanjut",
    "Performance tuning" : "Pemeliharaan performa",
    "Improving the config.php" : "Memperbaiki config.php",
    "Theming" : "Tema",
    "Hardening and security guidance" : "Panduan Keselamatan dan Keamanan",
    "Get the apps to sync your files" : "Dapatkan aplikasi untuk sinkronisasi berkas Anda",
    "Desktop client" : "Klien desktop",
    "Android app" : "Aplikasi Android",
    "iOS app" : "Aplikasi iOS",
    "Show First Run Wizard again" : "Tampilkan Penuntun Konfigurasi Awal",
    "Profile picture" : "Foto profil",
    "Upload new" : "Unggah baru",
    "Remove image" : "Hapus gambar",
    "Cancel" : "Batal",
    "Full name" : "Nama lengkap",
    "No display name set" : "Nama tampilan tidak diatur",
    "Email" : "Email",
    "Your email address" : "Alamat email Anda",
    "No email address set" : "Alamat email tidak diatur",
    "You are member of the following groups:" : "Anda adalah anggota dari grup berikut:",
    "Password" : "Sandi",
    "Unable to change your password" : "Gagal mengubah sandi Anda",
    "Current password" : "Sandi saat ini",
    "New password" : "Sandi baru",
    "Change password" : "Ubah sandi",
    "Language" : "Bahasa",
    "Help translate" : "Bantu menerjemahkan",
    "Unlimited" : "Tak terbatas",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Dikembangkan oleh {communityopen}komunitas ownCloud{linkclose}, {githubopen}kode sumber{linkclose} dilisensikan dibawah {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Name" : "Nama",
    "Username" : "Nama pengguna",
    "Done" : "Selesai",
    "Version" : "Versi",
    "Personal" : "Pribadi",
    "Admin" : "Admin",
    "Error" : "Kesalahan",
    "Show storage location" : "Tampilkan kolasi penyimpanan",
    "Show last log in" : "Tampilkan masuk terakhir",
    "Show user backend" : "Tampilkan pengguna backend",
    "Send email to new user" : "Kirim email kepada pengguna baru",
    "Show email address" : "Tampilkan alamat email",
    "E-Mail" : "E-Mail",
    "Create" : "Buat",
    "Admin Recovery Password" : "Sandi pemulihan Admin",
    "Enter the recovery password in order to recover the users files during password change" : "Masukkan sandi pemulihan untuk memulihkan berkas pengguna saat penggantian sandi",
    "Add Group" : "Tambah Grup",
    "Group" : "Grup",
    "Everyone" : "Semua orang",
    "Admins" : "Admin",
    "Default Quota" : "Kuota default",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Silakan masukkan jumlah penyimpanan (contoh: \"512 MB\" atau \"12 GB\")",
    "Other" : "Lainnya",
    "Full Name" : "Nama Lengkap",
    "Group Admin for" : "Grup Admin untuk",
    "Quota" : "Kuota",
    "Storage Location" : "Lokasi Penyimpanan",
    "User Backend" : "Pengguna Backend",
    "Last Login" : "Masuk Terakhir",
    "change full name" : "ubah nama lengkap",
    "set new password" : "setel sandi baru",
    "change email address" : "ubah alamat email",
    "Default" : "Default"
},
"nplurals=1; plural=0;");
